summaryrefslogtreecommitdiff
path: root/tools/clang-format/clang-format.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/clang-format/clang-format.py')
-rw-r--r--tools/clang-format/clang-format.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/tools/clang-format/clang-format.py b/tools/clang-format/clang-format.py
index 1d27985ea0..4077b4180c 100644
--- a/tools/clang-format/clang-format.py
+++ b/tools/clang-format/clang-format.py
@@ -26,9 +26,10 @@ import vim
# Change this to the full path if clang-format is not on the path.
binary = 'clang-format'
-# Change this to format according to other formatting styles (see
-# clang-format -help)
-style = 'LLVM'
+# Change this to format according to other formatting styles. See the output of
+# 'clang-format --help' for a list of supported styles. The default looks for
+# a '.clang-format' file to indicate the style that should be used.
+style = 'file'
# Get the current text.
buf = vim.current.buffer